@@ -28,7 +28,7 @@ from mitosheet.mito_analytics import log
 import os
 import pandas as pd
 from mitosheet.user import initialize_user
-from mitosheet.example import MitoWidget, sheet
+from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.save_utils import register_analysis
 from mitosheet.errors import CreationError, EditError
 from mitosheet._version import __version__
