@@ -2,7 +2,7 @@ from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, get_mito_type
 import pandas as pd
 import json
 
-def get_column_describe(send, event, wsc):
+def get_column_describe(event, wsc):
     """
     Sends back a string that can be parsed to a JSON object that
     contains _all_ the results from the series .describe function
@@ -36,16 +36,8 @@ def get_column_describe(send, event, wsc):
             describe_obj['median'] = str(round(series.median(), 2))
             describe_obj['sum'] = str(round(series.sum(), 2))
 
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': json.dumps(describe_obj)
-        })
+        return json.dumps(describe_obj)
     except:
         # As this is also a non-critical error, we don't want to display an error
         # message in the case of failure, so we just return nothing
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': ''
-        })
+        return ''
\ No newline at end of file
