@@ -367,6 +367,8 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
             range=ranges[Y]
         )
     )
+    # Determine if the graph was zoomed in
+    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
 
     log(f'generate_graph', {
         'params_graph_type': BAR,
@@ -374,11 +376,10 @@ def get_bar_chart(df, x_axis_column_headers, y_axis_column_headers):
         'params_x_axis_column_types': [get_mito_type(df[column_header]) for column_header in x_axis_column_headers] if x_axis_column_headers is not None else [],
         'params_y_axis_column_headers': y_axis_column_headers,
         'params_y_axis_column_types': [get_mito_type(df[column_header]) for column_header in y_axis_column_headers] if y_axis_column_headers is not None else [],
-        'params_filtered': filtered
+        'params_filtered': filtered,
+        'params_is_zoomed': is_zoomed
     })
 
-    # Determine if the graph was zoomed in
-    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
     return fig, is_zoomed
 
 def get_box_plot(axis, df, column_headers): 
@@ -587,6 +588,8 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
             range=ranges[Y]
         )
     )
+    # Determine if the graph was zoomed in
+    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
 
     log(f'generate_graph', {
         'params_graph_type': SCATTER,
@@ -594,11 +597,10 @@ def get_scatter_plot(df, x_axis_column_headers, y_axis_column_headers):
         'params_x_axis_column_types': [get_mito_type(df[column_header]) for column_header in x_axis_column_headers] if x_axis_column_headers is not None else [],
         'params_y_axis_column_headers': y_axis_column_headers,
         'params_y_axis_column_types': [get_mito_type(df[column_header]) for column_header in y_axis_column_headers] if y_axis_column_headers is not None else [],
-        'params_filtered': filtered
+        'params_filtered': filtered,
+        'params_is_zoomed': is_zoomed
     })
 
-    # Determine if the graph was zoomed in
-    is_zoomed = ranges[X][0] is not None or ranges[X][1] or ranges[Y][0] is not None or ranges[Y][1] is not None
     return fig, is_zoomed
 
 
@@ -651,7 +653,7 @@ def get_column_summary_graph(axis, df, axis_data_array):
     # we always return False as the second parameter
     return fig, False
 
-def get_graph(send, event, wsc):
+def get_graph(event, wsc):
     """
     Creates a graph of the passed parameters, and sends it back as a PNG
     string to the frontend for display.
@@ -696,12 +698,8 @@ def get_graph(send, event, wsc):
                 'params_graph_type': graph_type,
                 'params_failed_reason': 'no axis data'
             })
-            send({
-                'event': 'api_response',
-                'id': event['id'],
-                'data': ''
-            })
-            return
+
+            return ''
         if sheet_index is None or graph_type is None:
             # If no sheet_index or graph type is provided, return
             failed_reason = 'no selected_sheet_index' if sheet_index is None else 'no graph_type'
@@ -709,24 +707,14 @@ def get_graph(send, event, wsc):
                 'params_graph_type': graph_type,
                 'params_failed_reason': failed_reason
             })
-            send({
-                'event': 'api_response',
-                'id': event['id'],
-                'data': ''
-            })
-            return
+            return ''
         if x_axis and len(x_axis_column_headers) > 1 and y_axis and len(y_axis_column_headers) > 1:
             # If both axises have more than 1 series, return
             log(f'failed_generate_graph', {
                 'params_graph_type': graph_type,
                 'params_failed_reason': 'both axises have multiple columns'
             })
-            send({
-                'event': 'api_response',
-                'id': event['id'],
-                'data': ''
-            })
-            return
+            return ''
 
         # Create a copy of the dataframe, just for safety.
         df: pd.DataFrame = wsc.dfs[sheet_index].copy()
@@ -794,18 +782,10 @@ def get_graph(send, event, wsc):
         # Tell the frontend if the graph is zoomed in
         return_object['is_zoomed'] = is_zoomed
 
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': json.dumps(return_object),
-        })
+        return json.dumps(return_object),
 
     except Exception as e:
         # As not being able to make a graph is a non-critical error that doesn't
         # result from user interaction, we don't want to throw an error if something
         # weird happens, so we just return nothing in this case
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': ''
-        })
\ No newline at end of file
+        return ''
\ No newline at end of file
