@@ -4,7 +4,7 @@ from mitosheet.steps import STEP_TYPE_TO_STEP
 import json
 
 
-def get_saved_analysis_description(send, event, wsc):
+def get_saved_analysis_description(event, wsc):
     """
     Gets the description of the steps in the saved analysis, and sends
     it back to the frontend
@@ -17,12 +17,7 @@ def get_saved_analysis_description(send, event, wsc):
     
     try:
         if analysis_steps is None:
-            send({
-                'event': 'api_response',
-                'id': event['id'],
-                'data': ''
-            })
-            return
+            return ''
         
         analysis_descriptions = []
         for step_number in analysis_steps['steps']:
@@ -43,17 +38,9 @@ def get_saved_analysis_description(send, event, wsc):
                 'step_description': step_description
             })
 
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': json.dumps(analysis_descriptions)
-        })
+        return json.dumps(analysis_descriptions)
         
     except Exception as e:
         # As not being able to get the steps is not a critical failure, 
         # we return empty data if its not possible.
-        send({
-            'event': 'api_response',
-            'id': event['id'],
-            'data': ''
-        })
\ No newline at end of file
+        return ''
\ No newline at end of file
