@@ -19,7 +19,6 @@ Our general approach to logging can be understood as:
    with their result very effectively!
 """
 import platform
-import getpass
 import sys
 import subprocess
 
@@ -256,7 +255,6 @@ def identify():
             'version_python': sys.version_info,
             'version_mito': __version__,
             'version_jupyterlab': jupyterlab_version,
-            'user': getpass.getuser(),
             'operating_system': operating_system,
             'email': user_email,
             'local': local,
