@@ -72,17 +72,59 @@ def _update_column_formula_in_step(
         step['column_evaluation_graph'][sheet_index][new_dependency].add(column_header)
 
 
+def _get_fixed_invalid_formula(new_formula, address):
+    """
+    A helper function that, given a formula, will try and fix
+    any common errors with it. 
+
+    Currently, the common errors are just checking if the formula
+    is missing some number of parenthases at the end.
+
+    Returns the fixed formula. If it cannot fix the formula, then 
+    returns the original formula (so that execution continues as 
+    normal, to report the error to the user).
+    """
+    POTENTIAL_VALID_FORMULAS = [
+        # Check the original formula, just in case it actually is valid
+        new_formula,
+        new_formula + ')',
+        new_formula + '))',
+        new_formula + ')))',
+    ]
+    for fixed_formula in POTENTIAL_VALID_FORMULAS:
+        try:
+            # Parse the formula, and return if it is valid
+            parse_formula(fixed_formula, address, throw_errors=True)
+            return fixed_formula
+        except:
+            pass
+    
+    return new_formula
+
+
+
 def saturate_set_column_formula_step(
         curr_step,
         event
     ):
     """
-    Adds the old formula to the edit event.
+    Adds the old formula to the edit event. 
+    
+    Furthermore, manipulates the incoming formula to try and
+    make it valid if it is not. Does not always succede
     """
     sheet_index = event['sheet_index']
     column_header = event['column_header']
     event['old_formula'] = curr_step['column_spreadsheet_code'][sheet_index][column_header]
 
+    try:
+        # Try and parse the formula, letting it throw errors if it
+        # is invalid
+        parse_formula(event['new_formula'], column_header, throw_errors=True)
+    except:
+        event['new_formula'] = _get_fixed_invalid_formula(event['new_formula'], column_header)
+        
+
 def execute_set_column_formula_step(
         curr_step,
         sheet_index,
