@@ -47,34 +47,57 @@ FILTER_COLUMN_PARAMS = [
 
 
 # SOME CONSTANTS USED IN THE FILTER STEP ITSELF
-
+FC_EMPTY = 'empty'
+FC_NOT_EMPTY = 'not_empty'
 SHARED_FILTER_CONDITIONS = [
-    'empty',
-    'not_empty'
+    FC_EMPTY,
+    FC_NOT_EMPTY
 ]
 
+FC_BOOLEAN_IS_TRUE = 'boolean_is_true'
+FC_BOOLEAN_IS_FALSE = 'boolean_is_false'
+BOOLEAN_FILTER_CONDITIONS = [
+    FC_BOOLEAN_IS_TRUE,
+    FC_BOOLEAN_IS_FALSE
+]
+
+FC_STRING_CONTAINS = 'contains'
+FC_STRING_DOES_NOT_CONTAIN = 'string_does_not_contain'
+FC_STRING_EXACTLY = 'string_exactly'
+FC_STRING_NOT_EXACTLY = 'string_not_exactly'
 STRING_FILTER_CONDITIONS = [
-    'contains',
-    'string_does_not_contain',
-    'string_exactly',
-    'string_not_exactly'
+    FC_STRING_CONTAINS,
+    FC_STRING_DOES_NOT_CONTAIN,
+    FC_STRING_EXACTLY,
+    FC_STRING_NOT_EXACTLY
 ]
 
+FC_NUMBER_EXACTLY = 'number_exactly'
+FC_NUMBER_NOT_EXACTLY = 'number_not_exactly'
+FC_NUMBER_GREATER = 'greater'
+FC_NUMBER_GREATER_THAN_OR_EQUAL = 'greater_than_or_equal'
+FC_NUMBER_LESS = 'less'
+FC_NUMBER_LESS_THAN_OR_EQUAL = 'less_than_or_equal'
 NUMBER_FILTER_CONDITIONS = [
-    'number_exactly',
-    'number_not_exactly',
-    'greater',
-    'greater_than_or_equal',
-    'less',
-    'less_than_or_equal'
+    FC_NUMBER_EXACTLY,
+    FC_NUMBER_NOT_EXACTLY,
+    FC_NUMBER_GREATER,
+    FC_NUMBER_GREATER_THAN_OR_EQUAL,
+    FC_NUMBER_LESS,
+    FC_NUMBER_LESS_THAN_OR_EQUAL
 ]
 
+FC_DATETIME_EXACTLY = 'datetime_exactly'
+FC_DATETIME_GREATER = 'datetime_greater'
+FC_DATETIME_GREATER_THAN_OR_EQUAL = 'datetime_greater_than_or_equal'
+FC_DATETIME_LESS = 'datetime_less'
+FC_DATETIME_LESS_THAN_OR_EQUAL = 'datetime_less_than_or_equal'
 DATETIME_FILTER_CONDITIONS = [
-    'datetime_exactly',
-    'datetime_greater',
-    'datetime_greater_than_or_equal',
-    'datetime_less',
-    'datetime_less_than_or_equal',
+    FC_DATETIME_EXACTLY,
+    FC_DATETIME_GREATER,
+    FC_DATETIME_GREATER_THAN_OR_EQUAL,
+    FC_DATETIME_LESS,
+    FC_DATETIME_LESS_THAN_OR_EQUAL,
 ]
 
 def saturate_filter_event(curr_step, event):
@@ -229,12 +252,20 @@ def get_applied_filter(df, column_header, filter_):
 
     # First, we case on the shared conditions, to get them out of the way
     if condition in SHARED_FILTER_CONDITIONS:
-        if condition == 'empty':
+        if condition == FC_EMPTY:
             return df[column_header].isna()
-        elif condition == 'not_empty':
+        elif condition == FC_NOT_EMPTY:
             return df[column_header].notnull()
+    
+    if type_ == BOOLEAN_SERIES:
+        if condition not in BOOLEAN_FILTER_CONDITIONS:
+            raise Exception(f'Invalid condition passed to boolean filter {condition}')
 
-    if type_ == STRING_SERIES:
+        if condition == FC_BOOLEAN_IS_TRUE:
+            return df[column_header] == True
+        elif condition == FC_BOOLEAN_IS_FALSE:
+            return df[column_header] == False
+    elif type_ == STRING_SERIES:
         if condition not in STRING_FILTER_CONDITIONS:
             raise Exception(f'Invalid condition passed to string filter {condition}')
 
@@ -242,13 +273,13 @@ def get_applied_filter(df, column_header, filter_):
         if not isinstance(value, str):
             raise make_invalid_filter_error(value, STRING_SERIES)
 
-        if condition == 'contains':
+        if condition == FC_STRING_CONTAINS:
             return df[column_header].str.contains(value, na=False)
-        if condition == 'string_does_not_contain':
+        if condition == FC_STRING_DOES_NOT_CONTAIN:
             return ~df[column_header].str.contains(value, na=False)
-        elif condition == 'string_exactly':
+        elif condition == FC_STRING_EXACTLY:
             return df[column_header] == value
-        elif condition == 'string_not_exactly':
+        elif condition == FC_STRING_NOT_EXACTLY:
             return df[column_header] != value
 
     elif type_ == NUMBER_SERIES:
@@ -259,17 +290,17 @@ def get_applied_filter(df, column_header, filter_):
         if not isinstance(value, Number):
             raise make_invalid_filter_error(value, NUMBER_SERIES)
 
-        if condition == 'number_exactly':
+        if condition == FC_NUMBER_EXACTLY:
             return df[column_header] == value
-        elif condition == 'number_not_exactly':
+        elif condition == FC_NUMBER_NOT_EXACTLY:
             return df[column_header] != value
-        elif condition == 'greater':
+        elif condition == FC_NUMBER_GREATER:
             return df[column_header] > value
-        elif condition == 'greater_than_or_equal':
+        elif condition == FC_NUMBER_GREATER_THAN_OR_EQUAL:
             return df[column_header] >= value
-        elif condition == 'less':
+        elif condition == FC_NUMBER_LESS:
             return df[column_header] < value
-        elif condition == 'less_than_or_equal':
+        elif condition == FC_NUMBER_LESS_THAN_OR_EQUAL:
             return df[column_header] <= value
 
     elif type_ == DATETIME_SERIES:
@@ -285,15 +316,15 @@ def get_applied_filter(df, column_header, filter_):
             # and so in this case, we just default it to the minimum possible timestamp for now!
             timestamp = date.min
 
-        if condition == 'datetime_exactly':
+        if condition == FC_DATETIME_EXACTLY:
             return df[column_header] == timestamp
-        elif condition == 'datetime_greater':
+        elif condition == FC_DATETIME_GREATER:
             return df[column_header] > timestamp
-        elif condition == 'datetime_greater_than_or_equal':
+        elif condition == FC_DATETIME_GREATER_THAN_OR_EQUAL:
             return df[column_header] >= timestamp
-        elif condition == 'datetime_less':
+        elif condition == FC_DATETIME_LESS:
             return df[column_header] < timestamp
-        elif condition == 'datetime_less_than_or_equal':
+        elif condition == FC_DATETIME_LESS_THAN_OR_EQUAL:
             return df[column_header] <= timestamp
     else:
         raise Exception(f'Invalid type passed in filter {type_}')
@@ -357,29 +388,33 @@ def get_filter_string(df_name, column_header, filter_):
 
     FILTER_FORMAT_STRING_DICT = {
         # SHARED CONDITIONS
-        'empty': '{df_name}.{column_header}.isna()',
-        'not_empty': '{df_name}.{column_header}.notnull()',
+        FC_EMPTY: '{df_name}.{column_header}.isna()',
+        FC_NOT_EMPTY: '{df_name}.{column_header}.notnull()',
+
+        # BOOLEAN
+        FC_BOOLEAN_IS_TRUE: '{df_name}[\'{column_header}\'] == True',
+        FC_BOOLEAN_IS_FALSE: '{df_name}[\'{column_header}\'] == False',
 
         # NUMBERS
-        'number_exactly': '{df_name}[\'{column_header}\'] == {value}',
-        'number_not_exactly': '{df_name}[\'{column_header}\'] != {value}',
-        'greater': '{df_name}[\'{column_header}\'] > {value}',
-        'greater_than_or_equal': '{df_name}[\'{column_header}\'] >= {value}',
-        'less': '{df_name}[\'{column_header}\'] < {value}',
-        'less_than_or_equal': '{df_name}[\'{column_header}\'] <= {value}',
+        FC_NUMBER_EXACTLY: '{df_name}[\'{column_header}\'] == {value}',
+        FC_NUMBER_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != {value}',
+        FC_NUMBER_GREATER: '{df_name}[\'{column_header}\'] > {value}',
+        FC_NUMBER_GREATER_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] >= {value}',
+        FC_NUMBER_LESS: '{df_name}[\'{column_header}\'] < {value}',
+        FC_NUMBER_LESS_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] <= {value}',
         
         # STRINGS
-        'contains': '{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
-        'string_does_not_contain': '~{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
-        'string_exactly': '{df_name}[\'{column_header}\'] == \'{value}\'',
-        'string_not_exactly': '{df_name}[\'{column_header}\'] != \'{value}\'',
+        FC_STRING_CONTAINS: '{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
+        FC_STRING_DOES_NOT_CONTAIN: '~{df_name}[\'{column_header}\'].str.contains(\'{value}\', na=False)',
+        FC_STRING_EXACTLY: '{df_name}[\'{column_header}\'] == \'{value}\'',
+        FC_STRING_NOT_EXACTLY: '{df_name}[\'{column_header}\'] != \'{value}\'',
 
         # DATES
-        'datetime_exactly': '{df_name}[\'{column_header}\'] == pd.to_datetime(\'{value}\')',
-        'datetime_greater': '{df_name}[\'{column_header}\'] > pd.to_datetime(\'{value}\')',
-        'datetime_greater_than_or_equal': '{df_name}[\'{column_header}\'] >= pd.to_datetime(\'{value}\')',
-        'datetime_less': '{df_name}[\'{column_header}\'] < pd.to_datetime(\'{value}\')',
-        'datetime_less_than_or_equal': '{df_name}[\'{column_header}\'] <= pd.to_datetime(\'{value}\')',            
+        FC_DATETIME_EXACTLY: '{df_name}[\'{column_header}\'] == pd.to_datetime(\'{value}\')',
+        FC_DATETIME_GREATER: '{df_name}[\'{column_header}\'] > pd.to_datetime(\'{value}\')',
+        FC_DATETIME_GREATER_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] >= pd.to_datetime(\'{value}\')',
+        FC_DATETIME_LESS: '{df_name}[\'{column_header}\'] < pd.to_datetime(\'{value}\')',
+        FC_DATETIME_LESS_THAN_OR_EQUAL: '{df_name}[\'{column_header}\'] <= pd.to_datetime(\'{value}\')',            
     }
 
     return FILTER_FORMAT_STRING_DICT[condition].format(
