@@ -8,7 +8,7 @@ import pandas as pd
 import pytest
 
 from mitosheet.save_utils import write_analysis
-from mitosheet.example import MitoWidget, sheet
+from mitosheet.mito_widget import MitoWidget, sheet
 from mitosheet.utils import get_invalid_headers
 from mitosheet.tests.test_utils import create_mito_wrapper_dfs
 from mitosheet.transpiler.transpile import transpile
