@@ -10,9 +10,6 @@ import json
 from mitosheet.tests.test_utils import create_mito_wrapper, create_mito_wrapper_dfs
 
 
-def get_value_helper(sheet_data, row_index, column_index):
-    return sheet_data['data'][column_index]['columnData'][row_index]
-
 def test_sheet_json_displays_floats_correctly():
     df = pd.DataFrame({
         'value': [1.0, 2.0, None],
@@ -20,10 +17,10 @@ def test_sheet_json_displays_floats_correctly():
 
     mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 0) == '1.0'
-    assert get_value_helper(sheet_data, 1, 0) == '2.0'
-    assert get_value_helper(sheet_data, 2, 0) == 'NaN'
+    sheet_json = json.loads(mito.mito_widget.sheet_json)
+    assert sheet_json[0]['data'][0][0] == '1.0'
+    assert sheet_json[0]['data'][1][0] == '2.0'
+    assert sheet_json[0]['data'][2][0] == 'NaN'
 
 
 def test_sheet_json_displays_dates_correctly():
@@ -36,18 +33,19 @@ def test_sheet_json_displays_dates_correctly():
 
     mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 1) == '2005-10-25 00:00:00'
-    assert get_value_helper(sheet_data, 1, 1) == '2002-10-02 00:00:00'
-    assert get_value_helper(sheet_data, 2, 1)== '2001-11-14 00:00:00'
+    sheet_json = json.loads(mito.mito_widget.sheet_json)
+    assert sheet_json[0]['data'][0][1] == '2005-10-25 00:00:00'
+    assert sheet_json[0]['data'][1][1] == '2002-10-02 00:00:00'
+    assert sheet_json[0]['data'][2][1] == '2001-11-14 00:00:00'
 
 def test_sheet_displays_dates_with_non_standard_dtype():
     mito = create_mito_wrapper(['2016-01-31T19:29:50.000+0000', '2016-01-31T19:29:50.000+0000'])
     mito.change_column_dtype(0, 'A', 'datetime')
 
-    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 0) == '2016-01-31 19:29:50'
-    assert get_value_helper(sheet_data, 1, 0) == '2016-01-31 19:29:50'
+    sheet_json = json.loads(mito.mito_widget.sheet_json)
+    print(sheet_json)
+    assert sheet_json[0]['data'][0][0] == '2016-01-31 19:29:50'
+    assert sheet_json[0]['data'][1][0] == '2016-01-31 19:29:50'
 
 
 def test_sheet_json_holds_timed_deltas():
@@ -63,11 +61,11 @@ def test_sheet_json_holds_timed_deltas():
 
     mito.set_formula('=dob - dob2', 0, 'time_deltas', True)
     
-    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 2) == '364 days 13:44:45'
-    assert get_value_helper(sheet_data, 1, 2) == '-61 days +05:12:00'
-    assert get_value_helper(sheet_data, 2, 2) == '122 days 09:45:00'
-    assert get_value_helper(sheet_data, 3, 2) == 'NaT'
+    sheet_json = json.loads(mito.mito_widget.sheet_json)
+    assert sheet_json[0]['data'][0][2] == '364 days 13:44:45'
+    assert sheet_json[0]['data'][1][2] == '-61 days +05:12:00'
+    assert sheet_json[0]['data'][2][2] == '122 days 09:45:00'
+    assert sheet_json[0]['data'][3][2] == 'NaT'
 
 
 def test_sheet_json_holds_timed_deltas_non_standard_dtype():
@@ -82,8 +80,8 @@ def test_sheet_json_holds_timed_deltas_non_standard_dtype():
 
     mito = create_mito_wrapper_dfs(df)
     
-    sheet_data = json.loads(mito.mito_widget.sheet_data_json)[0]
-    assert get_value_helper(sheet_data, 0, 0) == '31 days 00:00:00'
-    assert get_value_helper(sheet_data, 1, 0) == '31 days 00:00:00'
-    assert get_value_helper(sheet_data, 2, 0) == '31 days 00:00:00'
-    assert get_value_helper(sheet_data, 3, 0) == '31 days 00:00:00'
\ No newline at end of file
+    sheet_json = json.loads(mito.mito_widget.sheet_json)
+    assert sheet_json[0]['data'][0][0] == '31 days 00:00:00'
+    assert sheet_json[0]['data'][1][0] == '31 days 00:00:00'
+    assert sheet_json[0]['data'][2][0] == '31 days 00:00:00'
+    assert sheet_json[0]['data'][3][0] == '31 days 00:00:00'
\ No newline at end of file
