@@ -10,7 +10,7 @@ for adding to lists in the user.json.
 """
 
 from mitosheet.mito_analytics import identify
-from mitosheet.user.user_utils import get_user_field, set_user_field
+from mitosheet.user import get_user_field, set_user_field
 
 
 APPEND_USER_FIELD_EVENT = 'append_user_field_update'
