@@ -11,7 +11,7 @@ Replays an existing analysis onto the sheet
 from copy import copy
 
 
-from mitosheet.utils import get_new_step_id
+from mitosheet.utils import get_new_id
 from mitosheet.steps.filter import execute_filter_column
 from mitosheet.save_utils import read_and_upgrade_analysis
 from mitosheet.steps import STEP_TYPE_TO_STEP
