@@ -9,7 +9,7 @@ Changes a specific field in the user.json file
 """
 
 from mitosheet.mito_analytics import identify
-from mitosheet.user.user_utils import set_user_field
+from mitosheet.user import set_user_field
 
 
 SET_USER_FIELD_EVENT = 'set_user_field_update'
