@@ -151,48 +151,6 @@ def df_to_json_dumpsable(df: pd.DataFrame):
     return json_obj
 
 
-def get_app_directory_from_jupyter_lab_path_output(output):
-    """
-    Takes the string output of `jupyter lab path` and returns the application folder for jupyter lab.
-
-    The output looks like:
-    Application directory:   <application path (depends on what system you are on)>
-    User Settings directory: <user settings path (depends on what system you are on)>
-    Workspaces directory: <workspace directory path (depends on what system you are on)>
-    
-    NOTE: this _should_ be able to handle any path we might want, including spaces, or Linux
-    or Windows or Mac paths.
-    """
-    return [x for x in output.split('\n') if x.startswith('Application directory:')][0][len('Application directory:'):].strip()
-
-
-def is_imported_correctly():
-    """
-    Helper function to determine if Mito is imported correctly. For this to be the case, 
-    Mito must be installed and enabled on a JupyterLab 2.0 instance, along with 
-    @jupyter-widgets/jupyterlab-manager.
-
-    We check this by finding out where jupyter lab is installed, and then seeing what 
-    extensions are installed. This is not perfect, but should detect most common cases
-    """
-    try:
-        # First, we get the directory that Jupyter is installed in
-        result = subprocess.run(["jupyter", "lab", "path"], capture_output=True)
-        stdout = result.stdout.decode()
-        app_directory = get_app_directory_from_jupyter_lab_path_output(stdout)
-        extension_directory = os.path.join(app_directory, 'extensions')
-        # Then, we check if the correct extensions are in the extension directory
-        if os.path.exists(extension_directory):
-            extensions = os.listdir(extension_directory)
-            includes_mito = len([extension for extension in extensions if extension.startswith('mitosheet')]) > 0
-            includes_jupyter_widgets = len([extension for extension in extensions if extension.startswith('jupyter-widgets-jupyterlab-manager')]) > 0
-            return includes_mito and includes_jupyter_widgets
-        
-        return False
-    except:
-        return False
-    
-
 def does_sheet_index_exist_within_step(step, sheet_index):
     """
     Returns true iff a sheet_index exists within a step
@@ -255,7 +213,7 @@ def get_random_id():
     """
     return str(uuid.uuid1())
 
-def get_new_step_id():
+def get_new_id():
     return str(uuid.uuid4())
 
 
